/*
 * Copyright (C) 2000  Ross Combs (rocombs@cs.nmsu.edu)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
#ifndef JUST_NEED_TYPES
#ifndef INCLUDED_UDPTEST_PROTOS
#define INCLUDED_UDPTEST_PROTOS

namespace pvpgn
{

	namespace client
	{

		extern int client_udptest_setup(char const * progname, unsigned short * lsock_port_ret);
		extern int client_udptest_recv(char const * progname, int lsock, unsigned short lsock_port, unsigned int timeout);

	}

}

#endif
#endif
